# Created by Jan Rummens at 18/01/2021
import json

import requests
from bs4 import BeautifulSoup
from jira import JIRA
from requests.auth import HTTPBasicAuth
from nemonet.cfg.config import Configuration


def merge_json_xml(scenario_file, jira_flag=False):
    #read the scenario file into memory
    soup = None
    with open(scenario_file + ".xml") as fp:
        soup = BeautifulSoup(fp, "lxml")
        fp.close()

    # read the json zephyr file into memory
    data_json = Configuration("dummy.json").get_data_structure()

    jira_id = 0
    #create an item in JIRA on the basis of the json configuration defintion

    if jira_flag:
        jira_connection = JIRA('https://jira.antwerpen.be', basic_auth=(data_json.plugin.zephyr.jira_user_name, data_json.plugin.zephyr.jira_pw))
        jira_id = jira_connection.create_issue( project=data_json.plugin.zephyr.project,
                                                summary=data_json.plugin.zephyr.summary,
                                                description=data_json.plugin.zephyr.description,
                                                issuetype={'name': 'Test'})


    #Merge json with xml
    root_tag = soup.graph
    new_tag_plugin = soup.new_tag("plugin")
    new_tag_zephyr = soup.new_tag("zephyr")
    new_tag_zephyr.attrs['project'] = data_json['plugin'][0]['zephyr']['project']
    new_tag_zephyr.attrs['summary'] = data_json['plugin'][0]['zephyr']['summary']
    new_tag_zephyr.attrs['description'] = data_json['plugin'][0]['zephyr']['description']
    #id needed and is returned by the jira system
    new_tag_zephyr.attrs['id'] = jira_id
    new_tag_plugin.append(new_tag_zephyr)
    root_tag.append(new_tag_plugin)
    root_tag.prettify()
    with open( scenario_file + ".xml", 'w') as f:
        f.write(str(root_tag))
        f.close()


def set_jira_item_status(jira_number, jira_project, status=1):
    data_json = Configuration("dummy.json").get_data_structure()
    jira_user_name = data_json.plugin.zephyr.jira_user_name
    jira_pw = data_json.plugin.zephyr.jira_pw

    baseURL = 'https://jira.antwerpen.be'
    jira_connection = JIRA(baseURL, basic_auth=(jira_user_name, jira_pw))
    issue = jira_connection.issue(jira_number)
    issue_id = issue.id
    jira_project = jira_connection.project( jira_project )
    jira_project_id = jira_project.id

    #get execution id
    headers = {'content-type': 'application/json', 'accept': 'application/json'}
    parameters = {'issueId': issue_id}
    get_execution_list = baseURL + ("/rest/zapi/latest/execution")
    response = requests.get(get_execution_list,
                     auth=HTTPBasicAuth(jira_user_name, jira_pw),
                     params=parameters,
                     headers=headers)
    response_dict = response.json()
    executions_list = response_dict['executions']
    execution_id = executions_list[0]['id']

    put_execution_status = baseURL + ("/rest/zapi/latest/execution/%d/execute" % (execution_id))
    headers = {'content-type': 'application/json'}
    payload_status = { "status": str(status) }
    r = requests.put(put_execution_status,
                     auth=HTTPBasicAuth(jira_user_name, jira_pw),
                     headers=headers,
                     params=parameters,
                     data=json.dumps(payload_status))


# Created by Jan Rummens at 19/01/2021
from bs4 import BeautifulSoup
from nemonet.plugin.handle_zephyr import set_jira_item_status

class Reporter(object):


    status_passed = 1
    status_failed = 2


    def publish(self, from_file_name, execution_status):
        with open( from_file_name + ".xml") as fp:
            soup = BeautifulSoup(fp, "lxml")
        for zephyr in soup.find_all('zephyr'):
            set_jira_item_status(jira_number=zephyr['id'], jira_project=zephyr['project'], status=execution_status)


import os
import tempfile
import uuid
import zipfile


class Store( object ):
    def __init__(self):
        self.aGuid = str(uuid.uuid4())
        self.dir_name = tempfile.mkdtemp(suffix='-video', prefix=self.aGuid)
        self.list_to_zip = [] # containing the complete file list with absolute path
        self.counter = 1

    def get_guid(self):
        return self.aGuid

    def get_dir_name(self):
        return self.dir_name

    def get_ffmpeg_glob(self):
        file_name_glob = '%s-??????.png' % (os.path.join(self.get_dir_name(), self.get_guid()))
        return file_name_glob

    def generate_file( self ):
        file_name = "%s-%06d.png" % ( self.get_guid(), self.counter )
        path_and_file = os.path.join( self.get_dir_name(), file_name )
        self.list_to_zip.append( path_and_file )
        self.counter += 1
        return path_and_file

    def add_file(self , name ):
        self.list_to_zip.append( name )

    def zip( self ):
        with zipfile.ZipFile(self.aGuid + '.zip', 'w') as myzip:
             for f in self.list_to_zip:
                 myzip.write(f,arcname=os.path.basename(f))


# Created by Jan Rummens at 10/02/2021
from bs4 import BeautifulSoup
from nemonet.cfg.config import Configuration

def merge_json_xml(scenario_file):
    #read the scenario file into memory
    soup = None
    with open(scenario_file + ".xml") as fp:
        soup = BeautifulSoup(fp, "lxml")
        fp.close()

    # read the json zephyr file into memory
    data_json = Configuration("dummy.json").get_data_structure()

    #TODO :

    #Merge json with xml
    root_tag = soup.graph
    new_tag_plugin = soup.new_tag("plugin")
    new_tag_junit = soup.new_tag("junit")
    new_tag_junit.attrs['testsuite_name'] = data_json.plugin[1].junit.testsuite_name


    new_tag_plugin.append(new_tag_junit)
    root_tag.append(new_tag_plugin)
    root_tag.prettify()
    with open( scenario_file + ".xml", 'w') as f:
        f.write(str(root_tag))
        f.close()


# Created by Jan Rummens at 18/01/2021
import unittest
from nemonet.cfg.config import Configuration
from nemonet.plugin.handle_junit_xml import merge_json_xml

xml_file="""<graph>
    <nodes>
        <node name="selenium"/>
        <node name="phrase"/>
        <node name="waiting"/>
    </nodes>
    <edges>
        <edge from="selenium" to="phrase"/>
        <edge from="phrase" to="waiting"/>
    </edges>
    <actions>
        <action xpath="" type="OPENURL" nodename="selenium" value="https://www.selenium.dev/"/>
        <action xpath="//*[@id='gsc-i-id1']" type="TEXTABLE-ENTER" nodename="phrase" value="computer vision"/>
        <action xpath="" type="WAIT" nodename="waiting" value="5"/>
    </actions>
</graph>"""

json_file="""{
    "plugin": [{
        "zephyr": {
            "project" : "FORE",
            "summary" : "summary",
            "description" : "description",
            "jira_client_access_key" : "A",
            "jira_client_secret_key" : "B",
            "zapi_client_access_key" : "C",
            "zapi_client_secret_key" : "D",
            "jira_user_name" : "user",
            "jira_pw" : "pw"
        }
    },
     {
        "junit": {
            "testsuite_name" : "FORE"
        }
    }]
}"""

class MyTestCase(unittest.TestCase):

    def setUp(self):
        fp = open("dummy.xml","w")
        fp.write(xml_file)
        fp.close()
        fp = open("dummy.json","w")
        fp.write(json_file)
        fp.close()

    def test_read_json(self):
        data = None
        data = Configuration("dummy.json").get_data_structure()

        self.assertTrue( data.plugin[1].junit.testsuite_name == 'FORE' )


    def test_update_xml(self):
        merge_json_xml("dummy")

if __name__ == '__main__':
    unittest.main()



# Created by Jan Rummens at 8/02/2021
import unittest
from nemonet.cfg.config import Configuration
import json

json_runner_config_1={
    "driver": {
        "headless": False,
        "browser": "chrome",
        "type": "selenium",
        "options": {
            "experimental_flags": [
                "same-site-by-default-cookies@2",
                "cookies-without-same-site-must-be-secure@2"
            ]
        }
    },
    "recording": {
        "switch": False
    }
}

json_runner_config_2={
    "driver": {
        "headless": True,
        "browser": "chrome",
        "type": "selenium",
    },
    "recording": {
        "switch": False
    }
}

class ConfigurationTestCase(unittest.TestCase):


    def setUp(self):
        self.filename_runner_config_1_json = 'runner_config_1.json'
        self.filename_runner_config_2_json = 'runner_config_2.json'
        self.dump_config_to_file( self.filename_runner_config_1_json, json_runner_config_1 )
        self.dump_config_to_file( self.filename_runner_config_2_json, json_runner_config_2 )

    def dump_config_to_file(self, file_name, config_data):
        with open(file_name, 'w') as fp:
            json.dump (config_data, fp, indent=4)
            fp.close()

    def test_local_config(self):
        cfg = Configuration("dummy.json")
        data = cfg.get_data_structure()
        self.assertTrue(
            data.plugin[0].zephyr == {
            "project" : "FORE",
            "summary" : "summary",
            "description" : "description",
            "jira_client_access_key" : "A",
            "jira_client_secret_key" : "B",
            "zapi_client_access_key" : "C",
            "zapi_client_secret_key" : "D",
            "jira_user_name" : "user",
            "jira_pw" : "pw"
        })
        self.assertTrue( data.plugin[0].zephyr.project == 'FORE' )
        self.assertTrue( data.plugin[0].zephyr.summary == 'summary' )
        self.assertTrue( data.plugin[0].zephyr.description == 'description' )

    def test_browser_config_1(self):
        cfg = Configuration( self.filename_runner_config_1_json )
        data = cfg.get_data_structure()
        self.assertTrue( data.driver.headless == False )
        self.assertTrue( data.driver.browser == "chrome")
        self.assertTrue( data.driver.type == "selenium" )

    def test_browser_config_2(self):
        cfg = Configuration( self.filename_runner_config_2_json )
        data = cfg.get_data_structure()
        self.assertTrue( data.driver.headless == True )
        self.assertTrue( data.driver.browser == "chrome")
        self.assertTrue( data.driver.type == "selenium" )

    def test_config_dict_convertion(self):
        cfg = Configuration()
        data = cfg.convert_to_dotted( json_runner_config_1 )
        self.assertTrue( data.driver.headless == False )
        self.assertTrue( data.driver.browser == "chrome" )
        self.assertTrue( data.driver.type == "selenium" )
        self.assertTrue( list( data.driver.options.experimental_flags ) == ["same-site-by-default-cookies@2", "cookies-without-same-site-must-be-secure@2"] )

    def test_config_none_extent(self):
        cfg = Configuration()
        data = cfg.convert_to_dotted(json_runner_config_1)
        with self.assertRaises(AttributeError):
            data.notpresent
        self.assertTrue( 'options' in data.driver )



if __name__ == '__main__':
    unittest.main()



# Created by Jan Rummens at 12/01/2021
import unittest
from nemonet.runner.vision_runner import Runner

class BrowserOptionsTestCase(unittest.TestCase):


    def test_chrome_options(self):
        runner = Runner(runner_config="runner_config.json")
        runner.execute_scenario("dummy")

    def test_chrome_options_headless(self):
        runner = Runner(runner_config="runner_config_headless.json")
        runner.execute_scenario("dummy")

if __name__ == '__main__':
    unittest.main()



import unittest

from bs4 import BeautifulSoup

from graphviz import Digraph

from nemonet.engines.graph import Graph, Vertex, Action

class MyTestCase(unittest.TestCase):

    def setUp(self):
        self.tree = Graph()
        self.buildGrapFromFile()

    def tearDown(self):
        self.tree = None

    def test_cases(self):
        startPoints = []
        endPoints = []
        nameList = self.tree.getAllNames()

        for name in nameList:
            v = self.tree.getVertex(name)
            if self.tree.isStart(v):
                startPoints.append(v)
            if self.tree.isEnd(v):
                endPoints.append(v)

        self.assertTrue(len(startPoints) == 2)
        self.assertTrue(len(endPoints) == 3)

        starters = [x.name for x in startPoints]
        enders = [x.name for x in endPoints]

        self.assertTrue( starters == ['A', 'B'] )
        self.assertTrue( enders == ['G', 'H', 'I'] )

        allThePaths = []

        for s in starters:
            for e in enders:
                pa = self.tree.find_all_paths(s, e)
                allThePaths = allThePaths + pa

        self.assertTrue( ['A', 'C', 'E', 'F', 'I'] in allThePaths )
        self.assertTrue( ['A', 'C', 'E', 'H'] in allThePaths )
        self.assertTrue( ['A', 'C', 'E', 'G'] in allThePaths )
        self.assertTrue( ['A', 'D', 'F', 'I'] in allThePaths )
        self.assertTrue( ['A', 'D', 'G'] in allThePaths )
        self.assertTrue( ['A', 'D', 'H'] in allThePaths )
        self.assertTrue( ['B', 'F', 'I'] in allThePaths )
        self.assertTrue( ['B', 'G'] in allThePaths )
        self.assertTrue( ['B', 'H'] in allThePaths )


    def buildGrapFromFile(self):
        dig = Digraph(comment='Type Screen')
        with open("graph-screen-type.xml") as fp:
            soup = BeautifulSoup(fp, "lxml")
        for node in soup.find_all('node'):
            v = Vertex(node['name'])
            self.tree.addVertex(v)
            dig.node(node['name'])

        for edge in soup.find_all('edge'):
            fromV = self.tree.getVertex(edge['from'])
            toV = self.tree.getVertex(edge['to'])
            self.tree.addEdge(fromV, toV)
            dig.edge(fromV.name,toV.name)
        for action in soup.find_all('action'):
            a = Action(action['xpath'], action['type'])
            v = self.tree.getVertex(action['nodename'])
            v.addAction(a)

        dig.render('testtypescreen')

if __name__ == '__main__':
    unittest.main()
